<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation>:خطا در Config.py</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation>خطا هنگام اجرای پلاگین:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation>مشکل در بارگذاری فایل.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation>فرمت فایل نامعتبر است.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation>مشکل در ذخیره کردن فایل.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation>مشکل در تجزیه XML:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation>کدگذاری (encoding) ناشناخته.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation>پاسخ گمشده در خط: </translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation>مشکل در بار گذاری پایگاه داده‌ها. فایل tmp ساخته می‌شود.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>(Mnemosyne) نموساین</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>خوب</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation>فایل وجود دارد: </translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation>ذخیره روی قبلی</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation>تکراری‌های حذف شده: </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation>کارتهایی با جوابهای مختلف برای این سؤال موجود است: </translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>ادغام و ویرایش</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation>ادغام نکن</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation>انجام شد!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="unfinished">شما هنوز این کارت را به یاد نمی‌آورید.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="unfinished">مانند گزینه »۰«٬ اما این آشناتر به نظر می‌رسد.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="unfinished">آن را کمتر نشان بده.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="unfinished">اکنون شما این کارت را حفظ شده‌اید٬</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="unfinished">و احتمالا آن را برای چند روز به یاد می‌آورید.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="unfinished">شما به کلی این کارت را فراموش کرده‌اید.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="unfinished">پاسخ صحیح اما به سختی. وقفه بسیار طولانی بود.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="unfinished">پاسخ صحیح٬ اما با سعی زیاد.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="unfinished">وقفه احتمالا طولانی بود.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="unfinished">پاسخ درست٬ با تلاش اندک.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="unfinished">وقفه احتمالا عادی بود.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="unfinished">پاسخ صحیح و بدون هیچ</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="unfinished">مشکلی٬ وقفه احتمالا خیلی کوتاه بود.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>(Mnemosyne) نموساین</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>Peter Bienstman :سازنده اصلی</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation>اطلاعات بیشتر: http://mnemosyne-proj.org</translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>درباره</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>مقوله‌های فعال</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>مقوله‌هایی که می‌خواهید فعال کنید را انتخاب کنید:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>هیچ کدام را فعال نکن</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>همه را فعال کن</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>خوب</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>انصراف</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;پیش فرض&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>(Mnemosyne) نموساین</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>کارت فعلی را رها کن؟</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>بله</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>خیر</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>پرسش:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>پاسخ:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>نوشته شده از:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>ترجمه:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>کارت از قبل در موجود بود.</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>نسخه دوم اضافه نشد.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>خوب</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>پاسخ‌های مختلفی برای این</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation>سؤال موجود است:
</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>ادغام و ویرایش</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>به همان صورت اضافه کن</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>اضافه نکن</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>اضافه کردن کارت</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>مقوله</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>پرسش:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>تلفظ:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>پاسخ:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>کارت برعکس هم اضافه کن</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>رتبه اولیه را انتخاب کنید:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>۰</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>شما این گزینه را هنوز به یاد نمی‌آورید.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>۱</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>شبیه &apos;۰&apos; اما این گزینه آشناتر است.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>۲</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>اکنون شما این کارت را حفظ شده‌اید و احتمالا آن‌را برای چند روز به یاد می‌آورید.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>۳</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>پاسخ صحیح٬ اما با سعی زیاد. وقفه احتمالا خیلی طولانی بود.</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>۴</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>پاسخ صحیح٬ با سعی اندک. وقفه احتمالا عادی بود.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>۵</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>پاسخ صحیح٬ اما بدون هیچ گونه مشکلی. وقفه احتمالا خیلی کوتاه بود.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>پرسش و پاسخ را تایپ کنید٬ سپس رتبه اولیه آن را انتخاب کنید.</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">پیش نمایش</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>تغییر مقوله</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>مقوله</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>بسیارخوب</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>تنظیمات مموساین</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>موس را روی دکمه‌ها معلق نگه دارید تا اطلاعات مربوط به آن ظاهر شود.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>ظاهر برنامه</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>فونت پرسش/پاسخ را انتخاب کنید</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>فونتی که هنگام نمایش پرسش یا پاسخ تنها٬ استفاده می‌شود را انتخاب کنید</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>فونت لیست کارت‌ها را انتخاب کنید</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>فونتی را که هنگام نمایش لیست کارت‌ها استفاده می‌شود را انتخاب کنید</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>سایز فونت‌های غیر لاتین را به این میزان افزایش بده</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>گاهی اوقات اشکال بعضی حروف غیر لاتین در سایز فونت لاتین ناخوانا می‌شود.</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>پوینت</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>ارسال گذارش</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>گزارش کارکرد را به صورت بی‌نام ارسال کن</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>آمار کارکرد را به صورت بی‌نام برای کمک به تحقیقات حافظه به اشتراک بگذار</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>اداره دونسخه‌ای‌ها</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>هنگام اضافه کردن کارت‌های جدید امکان وجود نسخه المثنی را بررسی کن</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>اجازه نسخه تکراری را در مقوله‌های مختلف بده</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>نحوه تکرار</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation type="obsolete">تعداد کارت‌های مرتبه »۰« برای یاد گرفتن با هم:</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>توجه: این میزان کارت‌هایی نیست که شما می‌خواهید روزانه حفظ کنید</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>بسیارخوب</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>پیش‌فرض‌ها</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>ویرایش کارت</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>مقوله:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>پرسش:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>پاسخ:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>بسیارخوب</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>پیش‌نمایش</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>لطفا صبر کنید...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>ویرایش</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>پیش‌نمایش</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>برعکس را هم اضافه کن</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>آمار</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>حذف کن</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>تغییر مقوله</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>برعکس را هم اضافه کن</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>برعکس این کارت‌ها هم اضافه شود؟</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>برعکس این کارت هم اضافه شود؟</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>نموساین</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>این ممکن است باعث اضافه شدن کارت‌های برعکسی شود</translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>که قبلا موجود بوده٬ پس ممکن است بعدا شما بخواهید که تمیزکاری </translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>.دو نسخه‌ای‌ها را انجام دهید</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>بله</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>خیر</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>مرتبه:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>آسانی:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>تکرارها:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>خطاها:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>روزهای بعد از آخرین مرور:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>روزهای قبل از مرور بعدی:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>بسیارخوب</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>این کارت‌ها را پاک کن؟</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>این کارت را پاک کن؟</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>متنی که تایپ کردید پیدا نشد.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>یکبار دیگر بگرد</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>بگرد</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="obsolete"></translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>پرسش</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>پاسخ</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>مقوله</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>ویرایش دسته کارت‌ها</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>بگرد</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>برای ویرایش یک کارت روی آن کلیک راست کنید.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>تمام فایل‌ها (*)</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>صادر کردن</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>صادر به فایل</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>فرمت فایل:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>فایلی که به آن صادر می‌کنید:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>جستجو</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>مقوله‌هایی که صادر می‌کنید:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>انتخاب همه</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>اطلاعات مربوط به یادگیری را هنگام صادر کردن صفر کن</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>بسیارخوب</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>انصراف</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>پیش فرض</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>تمام فایل‌ها (*)</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>وارد کردن</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>وارد کردن از طریق فایل</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>فرمت فایل:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>فایلی که از آن اطلاعات را وارد می‌کنید:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>پیدا کردن</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>کارت‌های بدون مقوله را در این مقوله قرار بده:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>توجه: تمام کارت‌ها به داده‌های کنونی اضافه خواهد شد.</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>اطلاعات مربوط به یادگیری را هنگام وارد کردن صفر کن</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>بسیارخوب</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>انصراف</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation type="unfinished">(*.mem) پایگاه داده‌های نموساین</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">جدید</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation type="unfinished">لطفا صبر کنید...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">نموساین</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation type="unfinished">کارت کنونی حذف شود؟</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished">بله</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished">خیر</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation type="unfinished">بازگشت در</translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation type="unfinished">.روز</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation type="unfinished">.مرور بعدی: امروز</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation type="unfinished">.مرور بعدی: فردا</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation type="unfinished">مرور بعدی در</translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="unfinished">روز بعد.</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">پرسش:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished">پیش فرض:</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation type="obsolete">پاسخ را نشان بده</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation type="unfinished">یادگیری جلوتر از برنامه‌ریزی</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation type="unfinished">روزهای قبل از مرور بعدی را انتخاب کنید:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation type="unfinished">مرتبه پاسخ خود را مشخص کنید:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation type="unfinished">برنامه‌ریزی شده: </translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation type="unfinished">حفظ نشده‌ها: </translation>
    </message>
    <message>
        <source>All: </source>
        <translation type="unfinished">همه: </translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">پاسخ را نشان بده</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne نموساین</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>پرسش:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>پاسخ:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>پاسخ را نشان بده</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>رتبه پاسخ خود را مشخص کنید:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>۰</translation>
    </message>
    <message>
        <source>0</source>
        <translation>۰</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>۱</translation>
    </message>
    <message>
        <source>1</source>
        <translation>۱</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>۲</translation>
    </message>
    <message>
        <source>2</source>
        <translation>۲</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>۳</translation>
    </message>
    <message>
        <source>3</source>
        <translation>۳</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>۴</translation>
    </message>
    <message>
        <source>4</source>
        <translation>۴</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>۵</translation>
    </message>
    <message>
        <source>5</source>
        <translation>۵</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>جدید</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>...باز کردن</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>ذخیره</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>...ذخیره دیگر</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>About</source>
        <translation>درباره</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>درباره</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>اضافه کردن کارت</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>اضافه کردن کارت</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>مقوله‌های فعال</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>ویرایش دسته کارت‌ها</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>ویرایش دسته کارت‌ها</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>وارد کردن</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>صادر کردن</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>نوار ابزار را نشان بده</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>ویرایش همین کارت</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>ویرایش همین کارت</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>حذف همین کارت</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>حذف همین کارت</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>تمیزکاری دونسخه‌ای‌ها</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>تنظیم نموساین</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>آشنا شدن با برنامه</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>آشنا شدن با برنامه</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>پاپین٬ پاپین</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>برگشت</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Space</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>نمایش آمار</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>نمایش آمار</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>نکته روز</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>نکته روز</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>نوار ابزار اصلی</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>فایل</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>دسته</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>تنظیمات</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>کمک</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>پیش فرض</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>پرسش:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>پیش نمایش کارت</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>پرسش:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>پاسخ:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>بسیارخوب</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>آشنا شدن با برنامه</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>من نموساین هستم٬ یک نوع پروانه که نام الهه حافظه در یونان باستان است.
من حفظ کردن و یادآوری پاسخ‌های پرسش‌هایتان را برای شما راحتتر و کارآمدتر می‌کنم٬ به این طریق که به شما کمک می‌کنم تمرکزتان را روی کارت‌هایی بگذارید که تمایل بیشتری به فراموش کردنشان دارید و وقتتان را سر مسائلی که بهتر می‌دانید هدر ندهید. برای این مقصود من زمان پرسش کردن را برنامه‌ریزی می‌کنم و شما احتیاج دارید که با رتبه دادن مشخص کنید چقدر جواب را خوب می‌دانید.
حالا بیاید نگاهی به معنی این رتبه‌ها بیندازیم. </translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>مقدمه</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>رتبه‌ها از »۰« تا »۵« تغییر می‌کنند. رتبه »۰« و »۱« زمانی استفاده می‌شوند که شما هنوز پاسخ را نمی‌دانید٬ یا آن را فراموش کرده‌اید. کارتی با رتبه »۱« نشانه آشناتر شدن با کارت است و میزان کمتری تکرار می‌شود.
من تا زمانی که شما رتبه »۲« یا بیشتر به کارت ندهید آن را از شما می‌پرسم. رتبه »۲« در اصل بدین معنی است که شما قادرید که پاسخ را برای یک یا دو روز به یاد بیاورید. این علامت انتقال از حافظه کوتاه مدت به بلند مدت است.
من این کارت را برای یکی از روز‌های آینده برنامه‌ریزی می‌کنم٬ زمانی که فکر کنم شما هنوز می‌توانید آن را با سعی اندک به یاد بیاورید٬ بدون آن که آن را کامل فراموش کرده باشید.
این بهینه‌ترین روش در فرایند یادگیری است.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>رتبه‌های ۰-۲</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>اگر در آینده من پرسش را خیلی زود بپرسم٬ و شما قادر به یادآوری سریع آن بدون هیچ گونه تلاشی بودید٬ رتبه کارت را ۵ بدهید. من این کارت را قبل از اینکه بار دیگرآنرا از شما بپرسم مدت بسیار طولانی‌ نگه می‌دارم.
اگر درست موقعی من کارت را نشان دادم٬ آنرا به یاد آوردید ٬ البته با سعی اندک٬ رتبه ۴ را انتخاب کنید.
از سوی دیگر اگر تلاش زیادی صرف یادآوری پاسخ شد٬ و تصور می‌کنید که من زمان زیادی منتظر جوابتان بودم٬ به کارت رتبه ۳ بدهید.
اگر شما اصلا موفق به یادآوردن آن نشدید٬ رتبه ۰ یا ۱ را انتخاب کنید. و من آنقدر آنرا از شما می‌پرسم تا موقعی که شما دیگر مطمئن شوید که می‌توانید آنرا برای چند روزی به یاد داشته باشید.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>رتبه‌های ۳-۵</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>اگر آمار برایتان مهم است٬ من می‌توانم گزارش مفصل مرورهای شما را نگهداری کنم.
بعلاوه من قادر به فرستادن گزارش کاملا بی نام به سایت مرکزی برای تجزیه و تحلیل می‌باشم٬ بدینسان شما می‌توانید به بهتر شدن من کمک کنید و در این راه٬ شما هم در تحقیقات حافظه بلند مدت شرکت کرده‌اید.
اگر نمی‌خواهید این کار را انجام دهید علامت درون مربع زیر را بردارید.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>فرستادن گزارش روزانه به صورت بی‌نام</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(شما می‌توانید هر وقت که خواستید این تنظیم را از طریق منوی تنظیمات نموساین تغییر دهید.)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>آمار</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>حالا شما برای شروع آماده‌اید!
کارت‌ها را با کلیک کردن روی علامت »+« اضافه کنید٬ این علامت در سمت چپ نوار ابزار است.
یادتان باشد که نیازی به ذخیره کردن کارهایتان نیست٬ من این کار را خودکار انجام می‌دهم.
برای بهترین نتیجه٬ من به شما مرور روزانه را پیشنهاد می‌کنم٬ گرچه در صورتی که شما مایل به مرور کارت‌ها زودتر از برنامه‌ریزی باشید٬ من می‌توانم از عهده کارهای اضافه بر بیایم.
برای راهنمایی بیشتر نگاهی به http://www.mnemosyne-proj.sourceforge.net بیندازید.  
یادگیری خوش بگذره!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>آماده برای شروع</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>الحاق تصویر</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>الحاق صدا</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>ورودی سه لبه</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>فایل‌های تصویری</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>الحاق تصویر</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>فایل‌های صوتی</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>الحاق صدا</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation type="obsolete">کارت‌های برنامه‌ریزی شده برای روزهای بعد:</translation>
    </message>
    <message>
        <source>In</source>
        <translation>در</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>روز :</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>تعداد کارت‌های رتبه‌های ذیل:
</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>رتبه</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation type="unfinished">مرتبه:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation type="unfinished">آسانی:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation type="unfinished">تکرارها:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation type="unfinished">خطاها:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation type="unfinished">روزهای بعد از آخرین مرور:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation type="unfinished">روزهای قبل از مرور بعدی:</translation>
    </message>
    <message>
        <source>Scheduled cards for next week:

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>مقوله</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>کارت</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>آمار</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>زمان‌بندی</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>رتبه‌ها</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>مقوله‌ها</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>بسیارخوب</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>برای نتیجه مطلوب بهتر است که مرور را هر روز انجام دهید.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>اگر برای چند روز به برنامه سر نزدید٬ نگران کار عقب مانده نباشید. هر چقدر که می‌رسید کارت‌ها را مرور کنید٬ بقیه به صورت خودکار برای آینده برنامه‌ریزی می‌شود.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>تعداد کارت‌های مرتبه »۰« که باید یکجا حفظ شوند٬ این تنظیم تعیین می‌کند که شما چه مقدار کارت‌های جدید را می‌خواهید در زمان یکسان حفظ کنید. این به شما نمی‌گوید که چقدر کارت در هر روز را حفظ می‌شوید. شما قضاوت می‌کنید که: بسته به احساسی که دارید٬ شما می‌خواهید کارت‌های بیشتری را یا کمتری را یاد بگیرید.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>سعی نکنید که مرور را هر روز انجام دهید٬ و همچنین نگران صفر کردن کارت‌های حفظ نشده و همچنین برنامه‌ریزی شده نباشید.</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>کارت‌های مرتبه »۱« با کارت‌های مرتبه »۰« تفاوت دارند بدینگونه که کمتر نشان داده می‌شوند و همچنین تابع قانون کارت‌های مرتبه »۰« که باید یکجا حفظ شوند نیستند.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>شما می‌توانید از دکمه‌های میانبر کی‌برد برای انجام مرورهایتان استفاده کنید. enter٬space و return به عنوان عملگر پیش‌فرض )نشان دادن پاسخ یا رتبه ۴(. دکمه‌های اعداد کی‌برد را برای رتبه دادن می‌توان استفاده کرد.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>شما می‌توانید مقوله‌هایی که می‌خواهید یاد بگیرید را در گزینه »مقوله‌های فعال« انتخاب کنید.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>بهتر آن است که تمام کارت‌ها را در یک پایگاه داده نگهداری و از مقوله‌ها برای سازمان دادنشان استفاده کنید. استفاده از گزینه »مقوله‌های فعال« بسیار راحت‌تر از بارگذاری و برداشتن داده‌های مختلف است. </translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>شما می‌توانید کارت‌ها را در گستره گوناگونی از فرمت‌ها وارد نموساین کنید: فایل‌های ‌txt که بوسیله tab مرتب شده‌اند٬ فایل‌های supermemo و ...</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>اگر کارت‌ها را در excel یا word دارید٬ آنها را با انکودینگ UTF-8 و مرتب شده بوسیله tab صادر )export( کنید تا قادر به وارد کردن به نموساین باشند.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>برای آنکه کارت‌ها را پرینت کنید آنها با فرمت txt صادر کنید تا بعدا بوسیله یک برنامه مانند word آنها را چاپ کنید. </translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>شما می‌توانید کارت‌هایتان را با فرمت xml با اشخاص دیگر به اشتراک بگذارید.</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>گاهی اوقات حروف الفبای غیر انگلیسی در مقایسه با حروف انگلیسی کوچک به نظر می‌رسند. اگر می‌خواهید که سایز حروف غیر انگلیسی را بزرگ کنید در عین حال سایز حروف انگلیسی تغییر نکند از تنظیم »سایز فونت‌های غیر لاتین را به این میزان افزایش بده« استفاده کنید.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>شما می‌توانید به کارت‌هایتان صدا و تصویر اضافه کنید. در پنجره »ویرایش کارت« قسمتی که سؤال یا جواب را وارد می‌کنید کلیک راست کنید تا منویی برای همین کار باز شود.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>توصیه می‌شود که فایل‌های صدا و تصویر را در دایرکتوری mnemosyne. نگه دارید. بدینگونه انتقال داده‌هایتان بین کامپیوترهای مختلف راحتتر می‌شود.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>وقتی کارت سه لبه اضافه می‌شود٬ دو کارت معمولی ساخته می‌شود. یکی سؤال: شکل نوشتاری کلمه و جواب: تلفظ و ترجمه آن است٬ و کارت دیگر سؤال: ترجمه کلمه و جواب: شکل نوشتاری کلمه و تلفظ آن می‌باشد.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>شما می‌توانید در کارت‌ها از HTML tag های ساده برای کنترل ظاهر شدن نوشته یا تصویرتان استفاده کنید.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>نموساین از LaTeX برای رندر (نمایش) فرمول‌های ریاضی استفاده می‌کند. به عنوان مثال: &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. )برای این منظور٬ شما نیاز به نصب LaTeX و dvipng دارید.(</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>بهترین راه برای زاپاس گرفتن از اطلاعاتتان در نموساین٬ کپی کردن دایرکتوری mnemosyne. )اگر توصبه‌های مربوط به نگهداری فایلهایتان در همان دایرکتوری را رعایت کرده باشید( و انتقال آن به درایو دیگری است. نموساین به صورت خودکار زاپاس اطلاعات را به صورت XML در دایرکتوری mnemosyne/backups نگه می‌دارد٬ اما اگر همین درایو از بین برود این روش خودکار به شما کمکی نخواهد کرد.</translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>شما می‌توانید نموساین را از USB فلش نیز اجرا کنید. دایرکتوری C:\Program Files\Mnemosyne را در USB فلش کپی کنید٬ سپس دایرکتوری mnemosyne. را درون دایرکتوری نموساین در USB کپی کنید.</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>اگر شما نموساین را در کامپیوترهای مختلف اجرا می‌کنید٬ یک ابزار دم دستی به نام Unison برای همزمان کردن اطلاعاتتان روی کامپیوترهای مختلف وجود دارد. برای اطلاعات بیشتر به وب‌سایت نموساین مراجعه کنید.</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>برای مرتب کردن کارت‌ها بر اساس سؤال یا جواب در پنجره Edit Deck روی عنوان ستون مربوطه کلیک کنید. برای تغییر جهت مرتب شدن یک بار دیگر روی عنوان کلیک کنید.</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>برای اطلاعات بیشتر در مورد کنترل دقیق‌تر روی تگ‌های LaTeX به سایت نموساین مراجعه کنید.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>کاربران پیشرفته برای تغییر نموساین براساس نیازهای شخصی‌شان می‌توانند فایل config.py را در دایرکتوری mnemosyne. ویرایش کنند. حتی برای اضافه کردن ویژگی‌های بیشتر به نموساین می‌توانید به آن plugin اضافه کنید. </translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>نکته روز</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>آیا می‌دانستید...؟</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>نکته‌ها را هنگام شروع برنامه نشان بده</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>قبلی</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>بعدی</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>بستن</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
</TS>
